@@ -186,6 +186,6 @@ x1^l/Ƌbx1^l/Ƌbx1^Ƌb0^ņb0^ņb/6A`/l!ÿb0\000+g˟^P\00
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/fp-wien/assets/banner3.png", "/var/www/html/staging-demo/themes/fp-wien/assets/banner3.png");
+        return new Source("", "@themes/fp-wien/assets/banner3.png", "/var/www/mautic-ktn/themes/fp-wien/assets/banner3.png");
     }
 }
